@@ -2,7 +2,6 @@
 
 from __future__ import annotations
 
-import logging
 from abc import ABCMeta, abstractmethod
 from pathlib import PurePosixPath
 from typing import TYPE_CHECKING
@@ -15,10 +14,6 @@ if TYPE_CHECKING:  # pragma: no cover
     from typing import Any
 
 
-# Globals
-logger = logging.getLogger(__name__)
-
-
 class RemoteHvcsBase(HvcsBase, metaclass=ABCMeta):
     """
     Interface for subclasses interacting with a remote VCS
