@@ -17,9 +17,8 @@ from tests.util import assert_exit_code
 
 if TYPE_CHECKING:
     from click import Command
-    from click.testing import CliRunner
-    from git import Repo
 
+    from tests.conftest import RunCliFn
     from tests.fixtures import UpdatePyprojectTomlFn
     from tests.fixtures.git_repo import BuiltRepoResult
 
@@ -39,7 +38,7 @@ HELP_EXIT_CODE = SUCCESS_EXIT_CODE
 def test_help_no_repo(
     help_option: str,
     command: Command,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     change_to_ex_proj_dir: None,
 ):
     """
@@ -70,7 +69,7 @@ def test_help_no_repo(
     )
 
     # Run the command with the help option
-    result = cli_runner.invoke(main, args, prog_name=MAIN_PROG_NAME)
+    result = run_cli(args, invoke_kwargs={"prog_name": MAIN_PROG_NAME})
 
     # Evaluate result
     assert_exit_code(HELP_EXIT_CODE, result, [MAIN_PROG_NAME, *args])
@@ -89,7 +88,7 @@ def test_help_no_repo(
 def test_help_valid_config(
     help_option: str,
     command: Command,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
 ):
     """
     Test that the help message is displayed when the current directory is a git repository
@@ -118,7 +117,7 @@ def test_help_valid_config(
     )
 
     # Run the command with the help option
-    result = cli_runner.invoke(main, args, prog_name=MAIN_PROG_NAME)
+    result = run_cli(args, invoke_kwargs={"prog_name": MAIN_PROG_NAME})
 
     # Evaluate result
     assert_exit_code(HELP_EXIT_CODE, result, [MAIN_PROG_NAME, *args])
@@ -133,11 +132,11 @@ def test_help_valid_config(
     (main, changelog, generate_config, publish, version),
     ids=lambda cmd: cmd.name,
 )
+@pytest.mark.usefixtures(repo_w_trunk_only_conventional_commits.__name__)
 def test_help_invalid_config(
     help_option: str,
     command: Command,
-    cli_runner: CliRunner,
-    repo_w_trunk_only_conventional_commits: Repo,
+    run_cli: RunCliFn,
     update_pyproject_toml: UpdatePyprojectTomlFn,
 ):
     """
@@ -171,7 +170,7 @@ def test_help_invalid_config(
     )
 
     # Run the command with the help option
-    result = cli_runner.invoke(main, args, prog_name=MAIN_PROG_NAME)
+    result = run_cli(args, invoke_kwargs={"prog_name": MAIN_PROG_NAME})
 
     # Evaluate result
     assert_exit_code(HELP_EXIT_CODE, result, [MAIN_PROG_NAME, *args])
@@ -192,7 +191,7 @@ def test_help_invalid_config(
 def test_help_non_release_branch(
     help_option: str,
     command: Command,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     repo_result: BuiltRepoResult,
 ):
     """
@@ -226,7 +225,7 @@ def test_help_non_release_branch(
     )
 
     # Run the command with the help option
-    result = cli_runner.invoke(main, args, prog_name=MAIN_PROG_NAME)
+    result = run_cli(args, invoke_kwargs={"prog_name": MAIN_PROG_NAME})
 
     # Evaluate result
     assert_exit_code(HELP_EXIT_CODE, result, [MAIN_PROG_NAME, *args])
