@@ -3,11 +3,12 @@ from __future__ import annotations
 from datetime import timedelta
 from itertools import count
 from pathlib import Path
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, cast
 
 import pytest
 
 from semantic_release.cli.config import ChangelogOutputFormat
+from semantic_release.version.version import Version
 
 import tests.conftest
 import tests.const
@@ -20,7 +21,15 @@ from tests.const import (
 )
 
 if TYPE_CHECKING:
-    from typing import Sequence
+    from typing import Any, Sequence
+
+    from semantic_release.commit_parser._base import CommitParser, ParserOptions
+    from semantic_release.commit_parser.conventional.parser import (
+        ConventionalCommitParser,
+    )
+    from semantic_release.commit_parser.emoji import EmojiCommitParser
+    from semantic_release.commit_parser.scipy import ScipyCommitParser
+    from semantic_release.commit_parser.token import ParseResult
 
     from tests.conftest import (
         GetCachedRepoDataFn,
@@ -39,6 +48,8 @@ if TYPE_CHECKING:
         ExProjectGitRepoFn,
         FormatGitHubMergeCommitMsgFn,
         GetRepoDefinitionFn,
+        RepoActionGitMerge,
+        RepoActionGitMergeDetails,
         RepoActions,
         RepoActionWriteChangelogsDestFile,
         TomlSerializableTypes,
@@ -85,13 +96,22 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
     changelog_md_file: Path,
     changelog_rst_file: Path,
     stable_now_date: GetStableDateNowFn,
+    default_conventional_parser: ConventionalCommitParser,
+    default_emoji_parser: EmojiCommitParser,
+    default_scipy_parser: ScipyCommitParser,
+    default_tag_format_str: str,
 ) -> GetRepoDefinitionFn:
     """
     Builds a repository with the GitHub Flow branching strategy using merge commits
     for alpha feature releases and official releases on the default branch.
     """
+    parser_classes: dict[CommitConvention, CommitParser[Any, Any]] = {
+        "conventional": default_conventional_parser,
+        "emoji": default_emoji_parser,
+        "scipy": default_scipy_parser,
+    }
 
-    def _get_repo_from_defintion(
+    def _get_repo_from_definition(
         commit_type: CommitConvention,
         hvcs_client_name: str = "github",
         hvcs_domain: str = EXAMPLE_HVCS_DOMAIN,
@@ -106,15 +126,21 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
             for i in count(step=1)
         )
         pr_num_gen = (i for i in count(start=2, step=1))
+        commit_parser = cast(
+            "CommitParser[ParseResult, ParserOptions]",
+            parser_classes[commit_type],
+        )
 
         changelog_file_definitions: Sequence[RepoActionWriteChangelogsDestFile] = [
             {
                 "path": changelog_md_file,
                 "format": ChangelogOutputFormat.MARKDOWN,
+                "mask_initial_release": mask_initial_release,
             },
             {
                 "path": changelog_rst_file,
                 "format": ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                "mask_initial_release": mask_initial_release,
             },
         ]
 
@@ -127,7 +153,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                     "commit_type": commit_type,
                     "hvcs_client_name": hvcs_client_name,
                     "hvcs_domain": hvcs_domain,
-                    "tag_format_str": tag_format_str,
+                    "tag_format_str": tag_format_str or default_tag_format_str,
                     "mask_initial_release": mask_initial_release,
                     "extra_configs": {
                         # Set the default release branch
@@ -141,6 +167,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                             "prerelease": True,
                             "prerelease_token": "alpha",
                         },
+                        "tool.semantic_release.commit_parser_options.ignore_merge_commits": ignore_merge_commits,
                         "tool.semantic_release.allow_zero_version": False,
                         **(extra_configs or {}),
                     },
@@ -149,7 +176,9 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
         )
 
         # Make initial release
-        new_version = "1.0.0"
+        new_version = Version.parse(
+            "1.0.0", tag_format=(tag_format_str or default_tag_format_str)
+        )
 
         repo_construction_steps.extend(
             [
@@ -159,6 +188,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_db_initial := "db_c1_initial_commit"),
                                     "conventional": INITIAL_COMMIT_MESSAGE,
                                     "emoji": INITIAL_COMMIT_MESSAGE,
                                     "scipy": INITIAL_COMMIT_MESSAGE,
@@ -168,6 +198,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                                     ),
                                 },
                                 {
+                                    "cid": (cid_db_c2_feat := "db_c2_feat"),
                                     "conventional": "feat: add new feature",
                                     "emoji": ":sparkles: add new feature",
                                     "scipy": "ENH: add new feature",
@@ -176,13 +207,15 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -190,6 +223,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                                 "details": {
                                     "new_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_db_initial, cid_db_c2_feat],
                                 },
                             },
                         ],
@@ -199,7 +233,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
         )
 
         # Make a fix and release it as an alpha release
-        new_version = "1.0.1-alpha.1"
+        new_version = Version.parse("1.0.1-alpha.1", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 {
@@ -217,6 +251,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_fib1_c1_fix := "fix_branch_c1_fix"),
                                     "conventional": "fix: correct some text\n\nResolves: #123",
                                     "emoji": ":bug: correct some text\n\nResolves: #123",
                                     "scipy": "MAINT: correct some text\n\nResolves: #123",
@@ -225,13 +260,15 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -239,6 +276,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                                 "details": {
                                     "new_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_fib1_c1_fix],
                                 },
                             },
                         ],
@@ -248,7 +286,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
         )
 
         # Update the fix and release another alpha release
-        new_version = "1.0.1-alpha.2"
+        new_version = Version.parse("1.0.1-alpha.2", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 {
@@ -257,6 +295,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_fib1_c2_fix := "fix_branch_1_c2_fix"),
                                     "conventional": "fix: adjust text to resolve",
                                     "emoji": ":bug: adjust text to resolve",
                                     "scipy": "MAINT: adjust text to resolve",
@@ -265,13 +304,15 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -279,6 +320,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                                 "details": {
                                     "new_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_fib1_c2_fix],
                                 },
                             },
                         ],
@@ -288,44 +330,45 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
         )
 
         # Merge the fix branch into the default branch and formally release it
-        new_version = "1.0.1"
-        fix_branch_pr_number = next(pr_num_gen)
+        new_version = Version.parse("1.0.1", tag_format=new_version.tag_format)
+
+        merge_def_type_placeholder: RepoActionGitMerge[RepoActionGitMergeDetails] = {
+            "action": RepoActionStep.GIT_MERGE,
+            "details": {
+                "branch_name": FIX_BRANCH_1_NAME,
+                "fast_forward": False,
+                "commit_def": convert_commit_spec_to_commit_def(
+                    {
+                        "cid": (cid_fib1_merge := "fix_branch_1_merge"),
+                        "conventional": (
+                            merge_msg := format_merge_commit_msg_github(
+                                pr_number=next(pr_num_gen),
+                                branch_name=FIX_BRANCH_1_NAME,
+                            )
+                        ),
+                        "emoji": merge_msg,
+                        "scipy": merge_msg,
+                        "datetime": next(commit_timestamp_gen),
+                        "include_in_changelog": not ignore_merge_commits,
+                    },
+                    commit_type,
+                    parser=commit_parser,
+                ),
+            },
+        }
+
         repo_construction_steps.extend(
             [
                 {
                     "action": RepoActionStep.GIT_CHECKOUT,
                     "details": {"branch": DEFAULT_BRANCH_NAME},
                 },
-                {
-                    "action": RepoActionStep.GIT_MERGE,
-                    "details": {
-                        "branch_name": FIX_BRANCH_1_NAME,
-                        "fast_forward": False,
-                        "commit_def": convert_commit_spec_to_commit_def(
-                            {
-                                "conventional": format_merge_commit_msg_github(
-                                    pr_number=fix_branch_pr_number,
-                                    branch_name=FIX_BRANCH_1_NAME,
-                                ),
-                                "emoji": format_merge_commit_msg_github(
-                                    pr_number=fix_branch_pr_number,
-                                    branch_name=FIX_BRANCH_1_NAME,
-                                ),
-                                "scipy": format_merge_commit_msg_github(
-                                    pr_number=fix_branch_pr_number,
-                                    branch_name=FIX_BRANCH_1_NAME,
-                                ),
-                                "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": not ignore_merge_commits,
-                            },
-                            commit_type,
-                        ),
-                    },
-                },
+                merge_def_type_placeholder,
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -333,6 +376,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                                 "details": {
                                     "new_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_fib1_merge],
                                 },
                             },
                         ],
@@ -342,7 +386,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
         )
 
         # Make a feature branch and release it as an alpha release
-        new_version = "1.1.0-alpha.1"
+        new_version = Version.parse("1.1.0-alpha.1", tag_format=new_version.tag_format)
 
         repo_construction_steps.extend(
             [
@@ -361,6 +405,9 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (
+                                        cid_feb1_c1_feat := "feat_branch_1_c1_feat"
+                                    ),
                                     "conventional": "feat(cli): add cli interface",
                                     "emoji": ":sparkles: add cli interface",
                                     "scipy": "ENH: add cli interface",
@@ -369,13 +416,15 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         )
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -383,6 +432,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                                 "details": {
                                     "new_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_feb1_c1_feat],
                                 },
                             },
                         ],
@@ -392,44 +442,45 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
         )
 
         # Merge the feature branch and officially release it
-        new_version = "1.1.0"
-        feat_branch_pr_number = next(pr_num_gen)
+        new_version = Version.parse("1.1.0", tag_format=new_version.tag_format)
+
+        merge_def_type_placeholder = {
+            "action": RepoActionStep.GIT_MERGE,
+            "details": {
+                "branch_name": FEAT_BRANCH_1_NAME,
+                "fast_forward": False,
+                "commit_def": convert_commit_spec_to_commit_def(
+                    {
+                        "cid": (cid_feb1_merge := "feat_branch_1_merge"),
+                        "conventional": (
+                            merge_msg := format_merge_commit_msg_github(
+                                pr_number=next(pr_num_gen),
+                                branch_name=FEAT_BRANCH_1_NAME,
+                            )
+                        ),
+                        "emoji": merge_msg,
+                        "scipy": merge_msg,
+                        "datetime": next(commit_timestamp_gen),
+                        "include_in_changelog": not ignore_merge_commits,
+                    },
+                    commit_type,
+                    parser=commit_parser,
+                ),
+            },
+        }
+
         repo_construction_steps.extend(
             [
                 {
                     "action": RepoActionStep.GIT_CHECKOUT,
                     "details": {"branch": DEFAULT_BRANCH_NAME},
                 },
-                {
-                    "action": RepoActionStep.GIT_MERGE,
-                    "details": {
-                        "branch_name": FEAT_BRANCH_1_NAME,
-                        "fast_forward": False,
-                        "commit_def": convert_commit_spec_to_commit_def(
-                            {
-                                "conventional": format_merge_commit_msg_github(
-                                    pr_number=feat_branch_pr_number,
-                                    branch_name=FEAT_BRANCH_1_NAME,
-                                ),
-                                "emoji": format_merge_commit_msg_github(
-                                    pr_number=feat_branch_pr_number,
-                                    branch_name=FEAT_BRANCH_1_NAME,
-                                ),
-                                "scipy": format_merge_commit_msg_github(
-                                    pr_number=feat_branch_pr_number,
-                                    branch_name=FEAT_BRANCH_1_NAME,
-                                ),
-                                "datetime": next(commit_timestamp_gen),
-                                "include_in_changelog": not ignore_merge_commits,
-                            },
-                            commit_type,
-                        ),
-                    },
-                },
+                merge_def_type_placeholder,
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -437,6 +488,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
                                 "details": {
                                     "new_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_feb1_merge],
                                 },
                             },
                         ],
@@ -447,7 +499,7 @@ def get_repo_definition_4_github_flow_repo_w_feature_release_channel(
 
         return repo_construction_steps
 
-    return _get_repo_from_defintion
+    return _get_repo_from_definition
 
 
 @pytest.fixture(scope="session")
