@@ -3,11 +3,12 @@ from __future__ import annotations
 from datetime import timedelta
 from itertools import count
 from pathlib import Path
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, cast
 
 import pytest
 
 from semantic_release.cli.config import ChangelogOutputFormat
+from semantic_release.version.version import Version
 
 import tests.conftest
 import tests.const
@@ -19,7 +20,15 @@ from tests.const import (
 )
 
 if TYPE_CHECKING:
-    from typing import Sequence
+    from typing import Any, Sequence
+
+    from semantic_release.commit_parser._base import CommitParser, ParserOptions
+    from semantic_release.commit_parser.conventional.parser import (
+        ConventionalCommitParser,
+    )
+    from semantic_release.commit_parser.emoji import EmojiCommitParser
+    from semantic_release.commit_parser.scipy import ScipyCommitParser
+    from semantic_release.commit_parser.token import ParseResult
 
     from tests.conftest import (
         GetCachedRepoDataFn,
@@ -73,11 +82,20 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
     changelog_md_file: Path,
     changelog_rst_file: Path,
     stable_now_date: GetStableDateNowFn,
+    default_conventional_parser: ConventionalCommitParser,
+    default_emoji_parser: EmojiCommitParser,
+    default_scipy_parser: ScipyCommitParser,
+    default_tag_format_str: str,
 ) -> GetRepoDefinitionFn:
     """
     Builds a repository with trunk-only committing (no-branching) strategy with
     official and prereleases releases.
     """
+    parser_classes: dict[CommitConvention, CommitParser[Any, Any]] = {
+        "conventional": default_conventional_parser,
+        "emoji": default_emoji_parser,
+        "scipy": default_scipy_parser,
+    }
 
     def _get_repo_from_definition(
         commit_type: CommitConvention,
@@ -93,15 +111,21 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
             (stable_now_datetime + timedelta(seconds=i)).isoformat(timespec="seconds")
             for i in count(step=1)
         )
+        commit_parser = cast(
+            "CommitParser[ParseResult, ParserOptions]",
+            parser_classes[commit_type],
+        )
 
         changelog_file_definitions: Sequence[RepoActionWriteChangelogsDestFile] = [
             {
                 "path": changelog_md_file,
                 "format": ChangelogOutputFormat.MARKDOWN,
+                "mask_initial_release": mask_initial_release,
             },
             {
                 "path": changelog_rst_file,
                 "format": ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                "mask_initial_release": mask_initial_release,
             },
         ]
 
@@ -114,7 +138,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                     "commit_type": commit_type,
                     "hvcs_client_name": hvcs_client_name,
                     "hvcs_domain": hvcs_domain,
-                    "tag_format_str": tag_format_str,
+                    "tag_format_str": tag_format_str or default_tag_format_str,
                     "mask_initial_release": mask_initial_release,
                     "extra_configs": {
                         # Set the default release branch
@@ -122,6 +146,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                             "match": r"^(main|master)$",
                             "prerelease": False,
                         },
+                        "tool.semantic_release.commit_parser_options.ignore_merge_commits": ignore_merge_commits,
                         "tool.semantic_release.allow_zero_version": True,
                         **(extra_configs or {}),
                     },
@@ -130,7 +155,9 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
         )
 
         # Make initial release
-        new_version = "0.1.0"
+        new_version = Version.parse(
+            "0.1.0", tag_format=(tag_format_str or default_tag_format_str)
+        )
 
         repo_construction_steps.extend(
             [
@@ -140,6 +167,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_c1_initial := "c1-initial_commit"),
                                     "conventional": INITIAL_COMMIT_MESSAGE,
                                     "emoji": INITIAL_COMMIT_MESSAGE,
                                     "scipy": INITIAL_COMMIT_MESSAGE,
@@ -149,6 +177,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                                     ),
                                 },
                                 {
+                                    "cid": (cid_c2_feat := "c2-feat"),
                                     "conventional": "feat: add new feature",
                                     "emoji": ":sparkles: add new feature",
                                     "scipy": "ENH: add new feature",
@@ -157,13 +186,15 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -171,6 +202,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                                 "details": {
                                     "new_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c1_initial, cid_c2_feat],
                                 },
                             },
                         ],
@@ -180,7 +212,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
         )
 
         # Make a fix and release it as a release candidate
-        new_version = "0.1.1-rc.1"
+        new_version = Version.parse("0.1.1-rc.1", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 {
@@ -189,6 +221,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_c3_fix := "c2-fix"),
                                     "conventional": "fix: correct some text\n\nfixes: #123\n",
                                     "emoji": ":bug: correct some text\n\nfixes: #123\n",
                                     "scipy": "MAINT: correct some text\n\nfixes: #123\n",
@@ -197,13 +230,15 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -211,6 +246,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                                 "details": {
                                     "new_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c3_fix],
                                 },
                             },
                         ],
@@ -220,7 +256,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
         )
 
         # Make an additional feature change and release it as a new release candidate
-        new_version = "0.2.0-rc.1"
+        new_version = Version.parse("0.2.0-rc.1", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 {
@@ -229,6 +265,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_c4_feat := "c4-feat"),
                                     "conventional": "feat: add some more text",
                                     "emoji": ":sparkles: add some more text",
                                     "scipy": "ENH: add some more text",
@@ -237,13 +274,15 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -251,6 +290,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                                 "details": {
                                     "new_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c4_feat],
                                 },
                             },
                         ],
@@ -260,7 +300,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
         )
 
         # Make an additional feature change and officially release the latest
-        new_version = "0.2.0"
+        new_version = Version.parse("0.2.0", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 {
@@ -269,6 +309,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_c5_feat := "c5-feat"),
                                     "conventional": "feat(cli): add cli command",
                                     "emoji": ":sparkles:(cli) add cli command",
                                     "scipy": "ENH: cli: add cli command",
@@ -277,13 +318,15 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -291,6 +334,7 @@ def get_repo_definition_4_trunk_only_repo_w_prerelease_tags(
                                 "details": {
                                     "new_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c5_feat],
                                 },
                             },
                         ],
