@@ -23,7 +23,7 @@ if TYPE_CHECKING:
             ":boom: Breaking changes\n\nMore description\n\nEven more description",
             LevelBump.MAJOR,
             ":boom:",
-            [":boom: Breaking changes", "More description", "Even more description"],
+            [":boom: Breaking changes"],
             ["More description", "Even more description"],
         ),
         # Minor bump
@@ -63,7 +63,7 @@ if TYPE_CHECKING:
             ":sparkles: Add a new feature\n\n:boom: should not be detected",
             LevelBump.MINOR,
             ":sparkles:",
-            [":sparkles: Add a new feature", ":boom: should not be detected"],
+            [":sparkles: Add a new feature"],
             [],
         ),
     ],
@@ -91,28 +91,27 @@ def test_default_emoji_parser(
 
 @pytest.mark.parametrize(
     "message, subject, merge_request_number",
-    # TODO: in v10, we will remove the merge request number from the subject line
     [
         # GitHub, Gitea style
         (
             ":sparkles: add new feature (#123)",
-            ":sparkles: add new feature (#123)",
+            ":sparkles: add new feature",
             "#123",
         ),
         # GitLab style
         (
             ":bug: fix regex in parser (!456)",
-            ":bug: fix regex in parser (!456)",
+            ":bug: fix regex in parser",
             "!456",
         ),
         # BitBucket style
         (
             ":sparkles: add new feature (pull request #123)",
-            ":sparkles: add new feature (pull request #123)",
+            ":sparkles: add new feature",
             "#123",
         ),
         # Both a linked merge request and an issue footer (should return the linked merge request)
-        (":bug: superfix (#123)\n\nCloses: #400", ":bug: superfix (#123)", "#123"),
+        (":bug: superfix (#123)\n\nCloses: #400", ":bug: superfix", "#123"),
         # None
         (":bug: superfix", ":bug: superfix", ""),
         # None but includes an issue footer it should not be considered a linked merge request
@@ -137,7 +136,6 @@ def test_parser_return_linked_merge_request_from_commit_message(
 
 @pytest.mark.parametrize(
     "message, linked_issues",
-    # TODO: in v10, we will remove the issue reference footers from the descriptions
     [
         *[
             # GitHub, Gitea, GitLab style
@@ -511,10 +509,9 @@ def test_parser_return_release_notices_from_commit_message(
     assert isinstance(result, ParsedCommit)
     assert tuple(notices) == result.release_notices
 
-    # TODO: v10, remove this
-    # full_description = str.join("\n\n", result.descriptions)
-    # full_notice = str.join("\n\n", result.release_notices)
-    # assert full_notice not in full_description
+    full_description = str.join("\n\n", result.descriptions)
+    full_notice = str.join("\n\n", result.release_notices)
+    assert full_notice not in full_description
 
 
 @pytest.mark.parametrize(
@@ -547,9 +544,7 @@ def test_parser_return_release_notices_from_commit_message(
                     {
                         "bump": LevelBump.NO_RELEASE,
                         "type": "Other",
-                        "descriptions": [
-                            "Merged in feat/my-awesome-stuff (pull request #10)"
-                        ],
+                        "descriptions": ["Merged in feat/my-awesome-stuff"],
                         "linked_merge_request": "#10",
                     },
                     {
@@ -560,7 +555,6 @@ def test_parser_return_release_notices_from_commit_message(
                             ":bug:(release-config): some commit subject",
                             "An additional description",
                             "Second paragraph with multiple lines that will be condensed",
-                            "Resolves: #12",
                             "Signed-off-by: author <author@not-an-email.com>",
                         ],
                         "linked_issues": ("#12",),
@@ -601,9 +595,7 @@ def test_parser_return_release_notices_from_commit_message(
                     {
                         "bump": LevelBump.NO_RELEASE,
                         "type": "Other",
-                        "descriptions": [
-                            "Merged in feat/my-awesome-stuff (pull request #10)"
-                        ],
+                        "descriptions": ["Merged in feat/my-awesome-stuff"],
                         "linked_merge_request": "#10",
                     },
                     {
@@ -614,7 +606,6 @@ def test_parser_return_release_notices_from_commit_message(
                             ":bug:(release-config): some commit subject",
                             "An additional description",
                             "Second paragraph with multiple lines that will be condensed",
-                            "Resolves: #12",
                             "Signed-off-by: author <author@not-an-email.com>",
                         ],
                         "linked_issues": ("#12",),
@@ -643,15 +634,9 @@ def test_parser_return_release_notices_from_commit_message(
                         "scope": "",
                         "descriptions": [
                             ":boom::bug: changed option name",
-                            "A breaking change description",
-                            "Closes: #555",
-                            # This is a bit unusual but its because there is no identifier that will
-                            # identify this as a separate commit so it gets included in the previous commit
-                            "invalid non-conventional formatted commit",
                         ],
                         "breaking_descriptions": [
                             "A breaking change description",
-                            "Closes: #555",
                             # This is a bit unusual but its because there is no identifier that will
                             # identify this as a separate commit so it gets included in the previous commit
                             "invalid non-conventional formatted commit",
@@ -702,7 +687,7 @@ def test_parser_squashed_commit_bitbucket_squash_style(
         assert expected["type"] == result.type
         # Optional
         assert expected.get("scope", "") == result.scope
-        # TODO: v10 change to tuples
+        # TODO: v11 change to tuples
         assert expected.get("descriptions", []) == result.descriptions
         assert expected.get("breaking_descriptions", []) == result.breaking_descriptions
         assert expected.get("linked_issues", ()) == result.linked_issues
@@ -749,7 +734,6 @@ def test_parser_squashed_commit_bitbucket_squash_style(
                             ":bug:(release-config): some commit subject",
                             "An additional description",
                             "Second paragraph with multiple lines that will be condensed",
-                            "Resolves: #12",
                             "Signed-off-by: author <author@not-an-email.com>",
                         ],
                         "linked_issues": ("#12",),
@@ -814,7 +798,6 @@ def test_parser_squashed_commit_bitbucket_squash_style(
                             ":bug:(release-config): some commit subject",
                             "An additional description",
                             "Second paragraph with multiple lines that will be condensed",
-                            "Resolves: #12",
                             "Signed-off-by: author <author@not-an-email.com>",
                         ],
                         "linked_issues": ("#12",),
@@ -839,12 +822,9 @@ def test_parser_squashed_commit_bitbucket_squash_style(
                         "type": ":boom:",
                         "descriptions": [
                             ":boom::bug: changed option name",
-                            "A breaking change description",
-                            "Closes: #555",
                         ],
                         "breaking_descriptions": [
                             "A breaking change description",
-                            "Closes: #555",
                         ],
                         "linked_issues": ("#555",),
                     },
@@ -896,7 +876,7 @@ def test_parser_squashed_commit_git_squash_style(
         assert expected["type"] == result.type
         # Optional
         assert expected.get("scope", "") == result.scope
-        # TODO: v10 change to tuples
+        # TODO: v11 change to tuples
         assert expected.get("descriptions", []) == result.descriptions
         assert expected.get("breaking_descriptions", []) == result.breaking_descriptions
         assert expected.get("linked_issues", ()) == result.linked_issues
@@ -933,11 +913,9 @@ def test_parser_squashed_commit_git_squash_style(
                         "type": ":bug:",
                         "scope": "release-config",
                         "descriptions": [
-                            # TODO: v10 removal of PR number from subject
-                            ":bug:(release-config): some commit subject (#10)",
+                            ":bug:(release-config): some commit subject",
                             "An additional description",
                             "Second paragraph with multiple lines that will be condensed",
-                            "Resolves: #12",
                             "Signed-off-by: author <author@not-an-email.com>",
                         ],
                         "linked_issues": ("#12",),
@@ -978,11 +956,9 @@ def test_parser_squashed_commit_git_squash_style(
                         "type": ":bug:",
                         "scope": "release-config",
                         "descriptions": [
-                            # TODO: v10 removal of PR number from subject
-                            ":bug:(release-config): some commit subject (#10)",
+                            ":bug:(release-config): some commit subject",
                             "An additional description",
                             "Second paragraph with multiple lines that will be condensed",
-                            "Resolves: #12",
                             "Signed-off-by: author <author@not-an-email.com>",
                         ],
                         "linked_issues": ("#12",),
@@ -1011,15 +987,11 @@ def test_parser_squashed_commit_git_squash_style(
                         "scope": "",
                         "descriptions": [
                             ":boom::bug: changed option name",
-                            "A breaking change description",
-                            "Closes: #555",
-                            # This is a bit unusual but its because there is no identifier that will
-                            # identify this as a separate commit so it gets included in the previous commit
-                            "* invalid non-conventional formatted commit",
                         ],
                         "breaking_descriptions": [
                             "A breaking change description",
-                            "Closes: #555",
+                            # This is a bit unusual but its because there is no identifier that will
+                            # identify this as a separate commit so it gets included in the previous commit
                             "* invalid non-conventional formatted commit",
                         ],
                         "linked_issues": ("#555",),
@@ -1068,7 +1040,7 @@ def test_parser_squashed_commit_github_squash_style(
         assert expected["type"] == result.type
         # Optional
         assert expected.get("scope", "") == result.scope
-        # TODO: v10 change to tuples
+        # TODO: v11 change to tuples
         assert expected.get("descriptions", []) == result.descriptions
         assert expected.get("breaking_descriptions", []) == result.breaking_descriptions
         assert expected.get("linked_issues", ()) == result.linked_issues
